@@ -232,15 +232,18 @@ class DummyFileGenerator:
         """
         absolute_path = file_scope_kwargs['absolute_path']
         row_count = file_scope_kwargs.get('row_count') or 0
-        file_size = file_scope_kwargs.get('file_size') * 1024 or 0
+        file_size = file_scope_kwargs.get('file_size') or 0
         file_encoding = file_scope_kwargs.get('file_encoding') or FILE_ENCODING
         file_line_ending = file_scope_kwargs.get('file_line_ending') or FILE_LINE_ENDING
 
         if not absolute_path:
             raise DummyFileGeneratorException(f'Missing mandatory argument absolute_path')
 
+        if file_size > 0:
+            file_size = file_size * 1024
+
         if row_count == 0 and file_size == 0:
-            # use default row_count from settings.py in case no row counts
+            # use default row_count in case no row counts
             # and no file size args provided:
             row_count = self.default_rowcount
 
